@@ -20,7 +20,8 @@
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include "gtk-compat.h"
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <pan/general/e-util.h>
 #include <pan/general/debug.h>
 #include <pan/general/file-util.h>
@@ -28,12 +29,16 @@
 #include <pan/general/utf8-utils.h>
 #include <pan/usenet-utils/mime-utils.h>
 #include <pan/tasks/queue.h>
-#include <pan/icons/pan-pixbufs.h>
 #include "pad.h"
 #include "render-bytes.h"
 #include "task-pane.h"
 #include "taskpane.ui.h"
 
+
+extern "C" {
+  #include <sys/stat.h>
+}
+
 enum
 {
   COL_TASK_POINTER,
@@ -49,7 +54,7 @@ void
 TaskPane :: get_selected_tasks_foreach (GtkTreeModel *model, GtkTreePath *, GtkTreeIter *iter, gpointer list_g)
 {
 
-  Task * task (0);
+  Task * task (nullptr);
   gtk_tree_model_get (model, iter, COL_TASK_POINTER, &task, -1);
   static_cast<tasks_t*>(list_g)->push_back (task);
 }
@@ -108,7 +113,7 @@ namespace
   {
 
     EvolutionDateMaker date_maker;
-    char * date(0);
+    char * date(nullptr);
     TaskUpload * tu (dynamic_cast<TaskUpload*>(task));
 
     if (tu)
@@ -144,8 +149,8 @@ namespace
 void
 TaskPane :: show_task_info(const tasks_t& tasks)
 {
-  
-  if (tasks.size() == 0) return;  
+
+  if (tasks.size() == 0) return;
   Task* task (tasks.front());
   if (!task) return;
 
@@ -157,7 +162,7 @@ TaskPane :: show_task_info(const tasks_t& tasks)
       GTK_DIALOG_DESTROY_WITH_PARENT,
       GTK_MESSAGE_INFO,
       GTK_BUTTONS_CLOSE,
-        buffer, NULL);
+        buffer, nullptr);
   g_signal_connect_swapped (w, "response", G_CALLBACK (gtk_widget_destroy), w);
   gtk_widget_show_all (w);
 
@@ -175,17 +180,17 @@ TaskPane:: on_tooltip_query(GtkWidget  *widget,
 
   if (!tp->_prefs.get_flag("show-taskpane-popups", true)) return false;
 
-  gtk_tooltip_set_icon_from_stock (tooltip, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
+  gtk_tooltip_set_icon_from_icon_name (tooltip, "dialog-information", GTK_ICON_SIZE_DIALOG);
 
   GtkTreeIter iter;
   GtkTreeView *tree_view = GTK_TREE_VIEW (widget);
   GtkTreeModel *model = gtk_tree_view_get_model (tree_view);
-  GtkTreePath *path(0);
+  GtkTreePath *path(nullptr);
 
   if (!gtk_tree_view_get_tooltip_context (tree_view, &x, &y, keyboard_tip, &model, &path, &iter))
     return false;
 
-  Task * task(0);
+  Task * task(nullptr);
   gtk_tree_model_get (model, &iter, COL_TASK_POINTER, &task, -1);
 
   char buffer[4096];
@@ -207,7 +212,7 @@ TaskPane::  do_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer
 {
   TaskPane * self (static_cast<TaskPane*>(userdata));
   GtkWidget * menu (gtk_ui_manager_get_widget (self->_uim, "/taskpane-popup"));
-  gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,
+  gtk_menu_popup (GTK_MENU(menu), nullptr, nullptr, nullptr, nullptr,
                   (event ? event->button : 0),
                   (event ? event->time : 0));
 }
@@ -231,7 +236,7 @@ TaskPane :: on_button_pressed (GtkWidget *treeview, GdkEventButton *event, gpoin
          if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
                                            (gint) event->x,
                                            (gint) event->y,
-                                           &path, NULL, NULL, NULL))
+                                           &path, nullptr, nullptr, nullptr))
          {
            gtk_tree_selection_unselect_all(selection);
            gtk_tree_selection_select_path(selection, path);
@@ -301,9 +306,9 @@ TaskPane :: prompt_user_for_new_dest (GtkWindow * parent, const Quark& current_p
   GtkWidget * w = gtk_file_chooser_dialog_new (_("Choose New Destination for Selected Tasks"),
                                                 GTK_WINDOW(parent),
                                                 GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-                                                NULL);
+                                               _("Cancel"), GTK_RESPONSE_CANCEL,
+                                               _("Save"), GTK_RESPONSE_ACCEPT,
+                                                nullptr);
   gtk_dialog_set_default_response (GTK_DIALOG(w), GTK_RESPONSE_ACCEPT);
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (w), TRUE);
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (w), prev_path.c_str());
@@ -366,7 +371,7 @@ TaskPane :: on_queue_tasks_added (Queue& queue, int index, int count)
 
   GtkTreeModel* model = gtk_tree_view_get_model(GTK_TREE_VIEW(_store));
   g_object_ref(model);
-  gtk_tree_view_set_model(GTK_TREE_VIEW(_store), NULL);
+  gtk_tree_view_set_model(GTK_TREE_VIEW(_store), nullptr);
 
   for (int i=0; i<count; ++i)
   {
@@ -390,14 +395,14 @@ TaskPane :: on_queue_task_removed (Queue&, Task& task, int index)
   const int list_index (find_task_index (_store, &task));
   assert (list_index == index);
   GtkTreeIter iter;
-  gtk_tree_model_iter_nth_child (GTK_TREE_MODEL(_store), &iter, NULL, index);
+  gtk_tree_model_iter_nth_child (GTK_TREE_MODEL(_store), &iter, nullptr, index);
   gtk_list_store_remove (_store, &iter);
 }
 
 void
 TaskPane :: on_queue_task_moved (Queue&, Task&, int new_index, int old_index)
 {
-  const int count (gtk_tree_model_iter_n_children (GTK_TREE_MODEL(_store), NULL));
+  const int count (gtk_tree_model_iter_n_children (GTK_TREE_MODEL(_store), nullptr));
   std::vector<int> v (count);
   for (int i=0; i<count; ++i) v[i] = i;
   if (new_index < old_index) {
@@ -420,9 +425,9 @@ void TaskPane :: on_queue_online_changed (Queue&, bool online)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(_online_toggle), online);
   g_signal_handler_unblock (_online_toggle, _online_toggle_handler);
 
-  gtk_image_set_from_stock (GTK_IMAGE(_online_image),
-                            online ? GTK_STOCK_CONNECT : GTK_STOCK_DISCONNECT,
-                            GTK_ICON_SIZE_BUTTON);
+  gtk_image_set_from_icon_name (GTK_IMAGE(_online_image),
+                                online ? "connect_established" : "connect_no",
+                                GTK_ICON_SIZE_BUTTON);
 }
 
 void
@@ -534,7 +539,7 @@ namespace
                 GtkTreeIter *iter,
                 Queue * queue)
   {
-    Task * task (0);
+    Task * task (nullptr);
     int state;
     gtk_tree_model_get (model, iter, COL_TASK_POINTER, &task,
                                      COL_TASK_STATE,  &state,
@@ -543,7 +548,7 @@ namespace
     if (!task) return;
 
     // build the state string
-    const char * state_str (0);
+    const char * state_str (nullptr);
     switch (state) {
       case Queue::RUNNING:  state_str = _("Running"); break;
       case Queue::DECODING: state_str = _("Decoding"); break;
@@ -608,14 +613,14 @@ namespace
       status.insert (0, buf);
     }
 
-    char * str (0);
+    char * str (nullptr);
     if (state == Queue::RUNNING || state == Queue::DECODING
         || state == Queue::ENCODING)
       str = g_markup_printf_escaped ("<b>%s</b>\n<small>%s</small>", descr, status.c_str());
     else
       str = g_markup_printf_escaped ("%s\n<small>%s</small>", descr, status.c_str());
     const std::string str_utf8 = clean_utf8 (str);
-    g_object_set(rend, "markup", str_utf8.c_str(), "xpad", 10, "ypad", 5, NULL);
+    g_object_set(rend, "markup", str_utf8.c_str(), "xpad", 10, "ypad", 5, nullptr);
     g_free (str);
     if (iconv_inited) g_free ((char*)descr);
   }
@@ -642,11 +647,11 @@ TaskPane :: ~TaskPane ()
 namespace
 {
   GtkWidget * add_button (GtkWidget   * box,
-                                      const gchar * stock_id,
+                                      const gchar * label,
                                       GCallback     callback,
                                       gpointer      user_data)
   {
-    GtkWidget * w = gtk_button_new_from_stock (stock_id);
+    GtkWidget * w = gtk_button_new_with_label (label);
     gtk_button_set_relief (GTK_BUTTON(w), GTK_RELIEF_NONE);
     if (callback)
       g_signal_connect (w, "clicked", callback, user_data);
@@ -658,45 +663,45 @@ namespace
 namespace
 {
 
-  void do_move_up        (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->up_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_move_down      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->down_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_move_top       (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->top_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_move_bottom    (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->bottom_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_show_info      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->show_info_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_stop           (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->stop_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_delete         (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->delete_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_restart        (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->restart_clicked_cb(0, static_cast<TaskPane*>(p)); }
-  void do_change_dest    (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->change_dest_clicked_cb(0, static_cast<TaskPane*>(p)); }
+  void do_move_up        (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->up_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_move_down      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->down_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_move_top       (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->top_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_move_bottom    (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->bottom_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_show_info      (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->show_info_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_stop           (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->stop_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_delete         (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->delete_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_restart        (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->restart_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
+  void do_change_dest    (GtkAction*, gpointer p)  { static_cast<TaskPane*>(p)->change_dest_clicked_cb(nullptr, static_cast<TaskPane*>(p)); }
 
   GtkActionEntry taskpane_popup_entries[] =
   {
 
-    { "move-up", NULL,
+    { "move-up", nullptr,
       N_("Move Up"), "",
       N_("Move Up"),
       G_CALLBACK(do_move_up) },
 
-    { "move-down", NULL,
+    { "move-down", nullptr,
       N_("Move Down"), "",
       N_("Move Down"),
       G_CALLBACK(do_move_down) },
 
-    { "move-top", NULL,
+    { "move-top", nullptr,
       N_("Move To Top"), "",
       N_("Move To Top"),
       G_CALLBACK(do_move_top) },
 
-    { "move-bottom", NULL,
+    { "move-bottom", nullptr,
       N_("Move To Bottom"), "",
       N_("Move To Bottom"),
       G_CALLBACK(do_move_bottom) },
 
-    { "show-info", NULL,
+    { "show-info", nullptr,
       N_("Show Task Information"), "",
       N_("Show Task Information"),
       G_CALLBACK(do_show_info) },
 
-    { "stop", NULL,
+    { "stop", nullptr,
       N_("Stop Task"), "",
       N_("Stop Task"),
       G_CALLBACK(do_stop) },
@@ -706,12 +711,12 @@ namespace
       N_("Delete Task"),
       G_CALLBACK(do_delete) },
 
-    { "restart", NULL,
+    { "restart", nullptr,
       N_("Restart Task"), "",
       N_("Restart Task"),
       G_CALLBACK(do_restart) },
 
-    { "change-dest", NULL,
+    { "change-dest", nullptr,
       N_("Change Download Destination"), "",
       N_("Change Download Destination"),
       G_CALLBACK(do_change_dest) }
@@ -725,8 +730,8 @@ TaskPane :: add_actions (GtkWidget * box)
   // action manager for popup
   _uim = gtk_ui_manager_new ();
   // read the file...
-  char * filename = g_build_filename (file::get_pan_home().c_str(), "taskpane.ui", NULL);
-  GError * err (0);
+  char * filename = g_build_filename (file::get_pan_home().c_str(), "taskpane.ui", nullptr);
+  GError * err (nullptr);
   if (!gtk_ui_manager_add_ui_from_file (_uim, filename, &err)) {
     g_clear_error (&err);
     gtk_ui_manager_add_ui_from_string (_uim, fallback_taskpane_ui, -1, &err);
@@ -742,7 +747,7 @@ TaskPane :: add_actions (GtkWidget * box)
 
    //add popup actions
   _pgroup = gtk_action_group_new ("taskpane");
-  gtk_action_group_set_translation_domain (_pgroup, NULL);
+  gtk_action_group_set_translation_domain (_pgroup, nullptr);
   gtk_action_group_add_actions (_pgroup, taskpane_popup_entries, G_N_ELEMENTS(taskpane_popup_entries), this);
   gtk_ui_manager_insert_action_group (_uim, _pgroup, 0);
 
@@ -752,7 +757,7 @@ namespace
 {
   gboolean on_popup_menu (GtkWidget * treeview, gpointer userdata)
   {
-    TaskPane::do_popup_menu (treeview, NULL, userdata);
+    TaskPane::do_popup_menu (treeview, nullptr, userdata);
     return true;
   }
 }
@@ -779,11 +784,6 @@ namespace
                                      GdkEventFocus * ,
                                      gpointer        )
   {
-#if !GTK_CHECK_VERSION(3,0,0)
-    gtk_widget_modify_text (w, GTK_STATE_NORMAL, NULL); // resets
-#else
-    gtk_widget_override_color (w, GTK_STATE_FLAG_NORMAL, NULL);
-#endif
     set_search_entry (w, search_text.c_str());
     return false;
   }
@@ -810,16 +810,6 @@ namespace
   {
     if (search_text.empty() && !gtk_widget_has_focus(w))
     {
-#if !GTK_CHECK_VERSION(3,0,0)
-      GdkColor c;
-      c.pixel = 0;
-      c.red = c.green = c.blue = 0xAAAA;
-      gtk_widget_modify_text (w, GTK_STATE_NORMAL, &c);
-#else
-      GdkRGBA c;
-      gdk_rgba_parse (&c, "0xAAA");
-      gtk_widget_override_color(w, GTK_STATE_FLAG_NORMAL, &c);
-#endif
       set_search_entry (w, _(mode_strings[search_mode]));
     }
   }
@@ -893,7 +883,7 @@ namespace
   void entry_icon_release (GtkEntry*, GtkEntryIconPosition icon_pos, GdkEventButton*, gpointer menu)
   {
     if (icon_pos == GTK_ENTRY_ICON_PRIMARY)
-      gtk_menu_popup (GTK_MENU(menu), 0, 0, 0, 0, 0, gtk_get_current_event_time());
+      gtk_menu_popup_at_pointer (GTK_MENU(menu), nullptr);
   }
 
   void entry_icon_release_2 (GtkEntry *entry, GtkEntryIconPosition icon_pos, GdkEventButton*, gpointer pane_gpointer)
@@ -902,7 +892,7 @@ namespace
       set_search_entry (GTK_WIDGET(entry), "");
       refresh_search_entry (GTK_WIDGET(entry));
       search_text.clear ();
-      search_entry_activated (NULL, pane_gpointer);
+      search_entry_activated (nullptr, pane_gpointer);
     }
   }
 
@@ -911,7 +901,7 @@ namespace
 
      if (search_text.empty()) return true;
 
-     Task *task(0);
+     Task *task(nullptr);
      /* Get value from column */
      gtk_tree_model_get( GTK_TREE_MODEL(model), iter, COL_TASK_POINTER, &task, -1 );
 
@@ -936,11 +926,11 @@ namespace
        {
           GRegexCompileFlags cf0((GRegexCompileFlags)0);
           GRegexMatchFlags mf0((GRegexMatchFlags)0);
-          GRegex* rex = g_regex_new (search_text.c_str(), cf0, mf0, NULL);
+          GRegex* rex = g_regex_new (search_text.c_str(), cf0, mf0, nullptr);
           if (!rex) return false;
           const bool match =
-            g_regex_match (rex, ta->get_article().subject.c_str(), G_REGEX_MATCH_NOTEMPTY, NULL) ||
-            g_regex_match (rex, ta->get_article().author.c_str(), G_REGEX_MATCH_NOTEMPTY, NULL);
+            g_regex_match (rex, ta->get_article().subject.c_str(), G_REGEX_MATCH_NOTEMPTY, nullptr) ||
+            g_regex_match (rex, ta->get_article().author.c_str(), G_REGEX_MATCH_NOTEMPTY, nullptr);
           g_regex_unref(rex);
           return match;
        }
@@ -973,17 +963,17 @@ TaskPane :: create_filter_entry ()
   GtkWidget * entry = gtk_entry_new ();
 //  _action_manager.disable_accelerators_when_focused (entry);
   g_object_set_data (G_OBJECT(entry), "pane", this);
-  g_signal_connect (entry, "focus-in-event", G_CALLBACK(search_entry_focus_in_cb), NULL);
-  g_signal_connect (entry, "focus-out-event", G_CALLBACK(search_entry_focus_out_cb), NULL);
+  g_signal_connect (entry, "focus-in-event", G_CALLBACK(search_entry_focus_in_cb), nullptr);
+  g_signal_connect (entry, "focus-out-event", G_CALLBACK(search_entry_focus_out_cb), nullptr);
   g_signal_connect (entry, "activate", G_CALLBACK(search_entry_activated), this);
   entry_changed_tag = g_signal_connect (entry, "changed", G_CALLBACK(search_entry_changed), this);
 
-  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                 GTK_ENTRY_ICON_PRIMARY,
-                                 GTK_STOCK_FIND);
-  gtk_entry_set_icon_from_stock( GTK_ENTRY( entry ),
-                                 GTK_ENTRY_ICON_SECONDARY,
-                                 GTK_STOCK_CLEAR );
+  gtk_entry_set_icon_from_icon_name( GTK_ENTRY( entry ),
+                                     GTK_ENTRY_ICON_PRIMARY,
+                                     "find");
+  gtk_entry_set_icon_from_icon_name( GTK_ENTRY( entry ),
+                                     GTK_ENTRY_ICON_SECONDARY,
+                                     "edit-clear" );
 
   bool regex = _prefs.get_flag ("use-regex", false);
   GtkWidget * menu = gtk_menu_new ();
@@ -991,7 +981,7 @@ TaskPane :: create_filter_entry ()
     search_mode = 1;
   else
     search_mode = 0;
-  GSList * l = 0;
+  GSList * l = nullptr;
   for (int i=0, qty=G_N_ELEMENTS(mode_strings); i<qty; ++i) {
     GtkWidget * w = gtk_radio_menu_item_new_with_label (l, _(mode_strings[i]));
     l = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM(w));
@@ -1018,61 +1008,64 @@ TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue), _prefs(prefs)
 
   GtkWidget * vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
-    GtkWidget * buttons = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
+  GtkWidget * buttons = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
 
-    w = _online_toggle = gtk_check_button_new ();
-    _online_toggle_handler = g_signal_connect (w, "clicked", G_CALLBACK(online_toggled_cb), &queue);
-    GtkWidget * i = _online_image = gtk_image_new ();
-    GtkWidget * l = gtk_label_new_with_mnemonic (_("_Online"));
-    GtkWidget * v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
-    gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
-    on_queue_online_changed (queue, queue.is_online());
-    gtk_box_pack_start (GTK_BOX(v), i, 0, 0, 0);
-    gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
-    gtk_container_add (GTK_CONTAINER(w), v);
-    gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
+  w = _online_toggle = gtk_check_button_new ();
+  _online_toggle_handler = g_signal_connect (w, "clicked", G_CALLBACK(online_toggled_cb), &queue);
+  GtkWidget * i = _online_image = gtk_image_new ();
+  GtkWidget * l = gtk_label_new_with_mnemonic (_("_Online"));
+  GtkWidget * v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+  gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
+  on_queue_online_changed (queue, queue.is_online());
+  gtk_box_pack_start (GTK_BOX(v), i, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
+  gtk_container_add (GTK_CONTAINER(w), v);
+  gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
+  gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
 
-    add_button (buttons, GTK_STOCK_GO_UP, G_CALLBACK(up_clicked_cb), this);
-    add_button (buttons, GTK_STOCK_GOTO_TOP, G_CALLBACK(top_clicked_cb), this);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
-    add_button (buttons, GTK_STOCK_GO_DOWN, G_CALLBACK(down_clicked_cb), this);
-    add_button (buttons, GTK_STOCK_GOTO_BOTTOM, G_CALLBACK(bottom_clicked_cb), this);
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
-    w = add_button (buttons, GTK_STOCK_REDO, G_CALLBACK(restart_clicked_cb), this);
-    gtk_widget_set_tooltip_text( w, _("Restart Tasks"));
-    w = add_button (buttons, GTK_STOCK_STOP, G_CALLBACK(stop_clicked_cb), this);
-    gtk_widget_set_tooltip_text( w, _("Stop Tasks"));
-    w = add_button (buttons, GTK_STOCK_DELETE, G_CALLBACK(delete_clicked_cb), this);
-    gtk_widget_set_tooltip_text( w, _("Delete Tasks"));
-    gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
-    w = add_button (buttons, GTK_STOCK_CLOSE, 0, 0);
-    g_signal_connect_swapped (w, "clicked", G_CALLBACK(gtk_widget_destroy), _root);
-    w = _popup_toggle = gtk_check_button_new ();
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), _prefs.get_flag("show-taskpane-popups", true));
-    l = gtk_label_new_with_mnemonic (_("Show popups"));
-    v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
-    gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
-    gtk_container_add (GTK_CONTAINER(w), v);
-    g_signal_connect (w, "clicked", G_CALLBACK(popup_toggled_cb), this);
-    gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
-    pan_box_pack_start_defaults (GTK_BOX(buttons), gtk_event_box_new()); // eat horizontal space
+  w = add_button (buttons, _("Move up"), G_CALLBACK(up_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Move task up"));
+  w = add_button (buttons, _("Move to top"), G_CALLBACK(top_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Move task to top of the download queue"));
+  gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
+  w = add_button (buttons, _("Move down"), G_CALLBACK(down_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Move task down"));
+  w = add_button (buttons, _("Move to bottom"), G_CALLBACK(bottom_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Move task to the bottom of the download queue"));
+  gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
+  w = add_button (buttons, _("Restart"), G_CALLBACK(restart_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Restart Tasks"));
+  w = add_button (buttons, _("Stop"), G_CALLBACK(stop_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Stop Tasks"));
+  w = add_button (buttons, _("Delete"), G_CALLBACK(delete_clicked_cb), this);
+  gtk_widget_set_tooltip_text( w, _("Delete Tasks"));
+  gtk_box_pack_start (GTK_BOX(buttons), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
+  w = add_button (buttons, _("Close"), nullptr, nullptr);
+  g_signal_connect_swapped (w, "clicked", G_CALLBACK(gtk_widget_destroy), _root);
+  w = _popup_toggle = gtk_check_button_new ();
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), _prefs.get_flag("show-taskpane-popups", true));
+  l = gtk_label_new_with_mnemonic (_("Show popups"));
+  v = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
+  gtk_box_pack_start (GTK_BOX(v), l, 0, 0, 0);
+  gtk_container_add (GTK_CONTAINER(w), v);
+  g_signal_connect (w, "clicked", G_CALLBACK(popup_toggled_cb), this);
+  gtk_box_pack_start (GTK_BOX(buttons), w, false, false, 0);
+  pan_box_pack_start_defaults (GTK_BOX(buttons), gtk_event_box_new()); // eat horizontal space
 
   gtk_box_pack_start (GTK_BOX(vbox), buttons, false, false, 0);
   gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
 
   // statusbar
   GtkWidget * hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
-  w = _status_label = gtk_label_new (0);
+  w = _status_label = gtk_label_new (nullptr);
   gtk_box_pack_start (GTK_BOX(hbox), w, false, false, PAD_SMALL);
 
   _store = gtk_list_store_new (NUM_COLS, G_TYPE_POINTER, G_TYPE_INT);
   _view = gtk_tree_view_new_with_model (GTK_TREE_MODEL(_store));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(_view), false);
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(_view), true);
   GtkCellRenderer * renderer = gtk_cell_renderer_text_new ();
-  GtkTreeViewColumn * col = gtk_tree_view_column_new_with_attributes (_("State"), renderer, NULL);
-  gtk_tree_view_column_set_cell_data_func (col, renderer, (GtkTreeCellDataFunc)render_state, &_queue, 0);
+  GtkTreeViewColumn * col = gtk_tree_view_column_new_with_attributes (_("State"), renderer, nullptr);
+  gtk_tree_view_column_set_cell_data_func (col, renderer, (GtkTreeCellDataFunc)render_state, &_queue, nullptr);
   gtk_tree_view_append_column (GTK_TREE_VIEW(_view), col);
   GtkTreeSelection * selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (_view));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
@@ -1087,20 +1080,19 @@ TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue), _prefs(prefs)
 
   // actions
   add_actions(_view);
-  gtk_window_add_accel_group (GTK_WINDOW(_root), gtk_ui_manager_get_accel_group (_uim));
 
   // search filter
   gtk_box_pack_start (GTK_BOX(hbox), gtk_separator_new(GTK_ORIENTATION_VERTICAL), 0, 0, 0);
   gtk_box_pack_start (GTK_BOX(hbox), create_filter_entry(), false, false, PAD);
   GtkTreeModel* initial_model= gtk_tree_view_get_model(GTK_TREE_VIEW( _view ));
-  GtkTreeModel* filter_model = gtk_tree_model_filter_new( initial_model, NULL );
-  gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER ( filter_model ),(GtkTreeModelFilterVisibleFunc) filter_visible_func, NULL, NULL);
+  GtkTreeModel* filter_model = gtk_tree_model_filter_new( initial_model, nullptr );
+  gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER ( filter_model ),(GtkTreeModelFilterVisibleFunc) filter_visible_func, nullptr, nullptr);
   gtk_tree_view_set_model( GTK_TREE_VIEW( _view ),filter_model);
   g_object_unref( filter_model );
 
   gtk_box_pack_start (GTK_BOX(vbox), hbox, false, false, PAD);
 
-  w = gtk_scrolled_window_new (NULL, NULL);
+  w = gtk_scrolled_window_new (nullptr, nullptr);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(w), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(w), GTK_SHADOW_IN);
   gtk_container_add (GTK_CONTAINER(w), _view);
